fixes #2081 : change parameter/variable name to 'foreign_key_checks', update change log
Signed-off-by:Andrew Podner <a.podner@me.com>
diff --git a/system/database/drivers/mysqli/mysqli_utility.php b/system/database/drivers/mysqli/mysqli_utility.php
index ff49490..2edf38c 100644
--- a/system/database/drivers/mysqli/mysqli_utility.php
+++ b/system/database/drivers/mysqli/mysqli_utility.php
@@ -77,8 +77,8 @@
 		// Build the output
 		$output = '';
 
-		// Do we need to include a statement to disable FK checks?
-		if ($fk_checks === FALSE)
+		// Do we need to include a statement to disable foreign key checks?
+		if ($foreign_key_checks === FALSE)
 		{
 			$output .= "SET foreign_key_checks = 0;".$newline;
 		}
@@ -188,8 +188,8 @@
 			$output .= $newline.$newline;
 		}
 
-		// Do we need to include a statement to re-enable FK checks?
-		if ($fk_checks === FALSE)
+		// Do we need to include a statement to re-enable foreign key checks?
+		if ($foreign_key_checks === FALSE)
 		{
 			$output .= "SET foreign_key_checks = 1;".$newline;
 		}